#!/bin/sh
# Run clearmake (or make if CCLT) in a separate window.  
#
# $1 is "strip" or "nostrip" depending on whether "basename" should
#    be applied to all targets.
# $2 is the directory to cd to before running clearmake.  
#
# The remaining args (if any) are clearmake targets.

STRIP=$1
DIR=$2
shift 2

if [ "$STRIP" = "nostrip" ]; then
    TARGETS="$*"
else
    if [ "$*" = "" ]; then
        TARGETS=""
    else
        # strip leading paths from pathnames
        for target in $*; do
            TARGETS="$TARGETS `basename $target`"
        done
    fi  
fi

OPTIONS_PN="$HOME/.gui_clearmake_options"
if [ -r $OPTIONS_PN ] ; then
    XTRA_MAKE_OPTIONS="`cat $OPTIONS_PN`"
else
    XTRA_MAKE_OPTIONS=""
fi
export XTRA_MAKE_OPTIONS
export TARGETS


#
# Japanese terminal support
#
if [ "$LANG" != "" -a "$XC_EXEC_NAME" = "xterm" ]; then
	LANG_PREFIX=`echo $LANG | cut -c 1,2 | tr '[A-Z]' '[a-z]'`
	if [ "$LANG_PREFIX" = "ja" -o "$LANG_PREFIX" = "jp" ]; then
	    # find kanji terminal command
	    kanji_term_cmd=`type gnome-terminal 2> /dev/null | awk '{ print $NF }'`
	    if [ "$kanji_term_cmd" != "" ]; then
	       TERM_FLAG="--disable-factory"
	    else
		kanji_term_cmd=`type aterm 2> /dev/null | awk '{ print $NF }'`	       
		if [ "$kanji_term_cmd" = "" ]; then
		    kanji_term_cmd=`type kterm 2> /dev/null | awk '{ print $NF }'`
		    LANG_SUFFIX=`echo $LANG | cut -c 7,8,9,10| tr '[A-Z]' '[a-z]'`
		    ORIG_LANG_PREFIX=`echo $LANG | cut -c 1,2`
		    if [ "$LANG_SUFFIX" = "sjis" -o "$ORIG_LANG_PREFIX" = "Ja" ]; then
			TERM_FLAG="-km sjis"
		    else
			TERM_FLAG="-km euc"
		    fi
		fi
	    fi
	    if [ "$kanji_term_cmd" != "" ]; then
		XC_EXEC_PNAME=$kanji_term_cmd; export XC_EXEC_PNAME
	    else
		TERM_FLAG=""
	    fi
	fi
fi

cat <<! >/tmp/clearmake.$$
#!/bin/sh
# TRANSLATE quoted string after echo command
trap 'echo; echo "==== f $SHELL JnĂ܂..."; exec $SHELL' 1 2 3 9 15

# SGI xwsh doesn't inherit stty settings (without .wshttymodestty)
# so you can't quit out of commands. We compensate by setting 'intr' to ^C
#
if [ "$XC_EXEC_NAME" = "xwsh" ] ; then
    if [ ! -r $HOME/.wshttymodestty ] ; then
	stty intr '^C' 2>/dev/null
    fi
fi

if [ "\$XTRA_MAKE_OPTIONS" != "" ] ; then
# TRANSLATE "Running:"
    echo ==== sĂ܂: $CLEARCASE_CM "\$XTRA_MAKE_OPTIONS" "\$TARGETS"
else
# TRANSLATE "Running:"
    echo ==== sĂ܂: $CLEARCASE_CM "\$TARGETS"
fi
!

if [ "$DIR" != "" ]; then
    echo "cd \"$DIR\"" >>/tmp/clearmake.$$
fi

echo $CLEARCASE_CM $XTRA_MAKE_OPTIONS $TARGETS >>/tmp/clearmake.$$

cat <<! >>/tmp/clearmake.$$

# TRANSLATE quoted string after echo command
echo "==== $CLEARCASE_CM ܂B $SHELL JnĂ܂..."
exec $SHELL
!

chmod +x /tmp/clearmake.$$

if [ "$XC_SCROLLBAR_FLAG" != "" ] ; then
    SB_ARGS="$XC_SCROLLBAR_FLAG"
    if [ "$XC_SCROLLBAR_ARG" != "" ] ; then
        SB_ARGS="$SB_ARGS $XC_SCROLLBAR_ARG"
    fi
fi

if [ "$XC_SAVE_LINES_FLAG" != "" ] ; then
    SB_ARGS="$SB_ARGS $XC_SAVE_LINES_FLAG 500"
fi

unset ATRIA_FORCE_GUI
($XC_EXEC_PNAME $TERM_FLAG $SB_ARGS $XC_COMMAND_FLAG /tmp/clearmake.$$ ; rm /tmp/clearmake.$$)
